Skip to contents

A wrapper on gsdd::gss() to by default get all Growing Seasons ignoring truncation. For more information see gsdd::gss().

Usage

gss(x, min_length = 120, ignore_truncation = "end", pick = "all", msgs = TRUE)

Arguments

x

A data frame with two columns date and temperature. date, which must be of class Date provides the dates and temperature which must be a numeric vector provides the mean daily water temperature in degrees centigrade.

min_length

A whole number of the minimum number of values to consider.

ignore_truncation

A flag specifying whether to ignore truncation of the mean daily water temperature vector or a string of "start", "end", "none" (equivalent to FALSE) or "both" (equivalent to TRUE) specifying which type of truncation to ignore.

pick

A string specifying which 'season' to pick when more than one is present. One of "longest", "shortest", "first" or "last", or the season with the "biggest" or "smallest" GSDD, or "all" to use every season. By default "all".

msgs

A flag specifying whether to provide messages.

See also

gsdd::gss(), gsdd() and gss().

Examples

gss(gsdd::temperature_data)
#> # A tibble: 1 × 5
#> # Groups:   year [1]
#>    year start_dayte end_dayte   gsdd truncation
#>   <int> <date>      <date>     <dbl> <chr>     
#> 1  2019 1971-03-20  1971-11-07 3899. none