A wrapper on gsdd::gdd() to get the Growing Degree Days up to a date for
the longest growing season.
Usage
gdd(x, end_date = as.Date("1972-09-30"), min_length = 60, msgs = TRUE)Arguments
- x
A data frame with two columns
dateandtemperature.date, which must be of class Date provides the dates andtemperaturewhich must be a numeric vector provides the mean daily water temperature in degrees centigrade.- end_date
A Date scalar of the last date within each year to consider (the year is ignored).
- min_length
A whole number of the minimum number of values to consider.
- msgs
A flag specifying whether to provide messages.
See also
gsdd::gdd(), gsdd() and gss().
Examples
gdd(gsdd::temperature_data)
#> # A tibble: 1 × 2
#> year gdd
#> <int> <dbl>
#> 1 2019 3605.