A wrapper on gsdd::gsdd() to get the Growing Season Degree Days for
the longest growing season.
Arguments
- x
A data frame with two columns
dateandtemperature.date, which must be of class Date provides the dates andtemperaturewhich must be a numeric vector provides the mean daily water temperature in degrees centigrade.- min_length
A whole number of the minimum number of values to consider.
- msgs
A flag specifying whether to provide messages.
See also
gsdd::gsdd(), gsdd() and gss().
Examples
gsdd(gsdd::temperature_data)
#> # A tibble: 1 × 2
#> year gsdd
#> <int> <dbl>
#> 1 2019 3899.