A wrapper on gsdd::gss_plot() to by default
plot all Growing Seasons ignoring truncation.
For more information see gsdd::gss_plot().
Usage
gss_plot(
x,
min_length = 60,
ignore_truncation = TRUE,
pick = "all",
latex = FALSE,
nrow = NULL,
ncol = NULL,
msgs = TRUE
)Arguments
- x
A data frame with two columns
dateandtemperature.date, which must be of class Date provides the dates andtemperaturewhich must be a numeric vector provides the mean daily water temperature in degrees centigrade.- min_length
A whole number of the minimum number of values to consider.
- ignore_truncation
A flag specifying whether to ignore truncation of the mean daily water temperature vector or a string of "start", "end", "none" (equivalent to FALSE) or "both" (equivalent to TRUE) specifying which type of truncation to ignore.
- pick
A string specifying which 'season' to pick when more than one is present. One of "longest", "shortest", "first" or "last", or the season with the "biggest" or "smallest" GSDD, or "all" to use every season. By default "all".
- latex
A flag specifying whether to use LaTeX to include degree symbol in y-axis label.
- nrow
A count of the number of rows to facet by.
- ncol
A count of the number of columns to facet by.
- msgs
A flag specifying whether to provide messages.
See also
gsdd::gss_plot() and gss().
Examples
gss_plot(gsdd::temperature_data)